# coding: utf-8

# flake8: noqa

"""
    😸 Cheshire-Cat API

    Production ready AI assistant framework

    The version of the OpenAPI document: 1.3.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.4"

from cheshire_cat_api.cat_client import CatClient
from cheshire_cat_api.config import Config

# This stuff is kept commented to avoid people accessing it from cheshire_cat_api.
# Only visible elements are the two above

# # import apis into sdk package
# from cheshire_cat_api.api.embedder_api import EmbedderApi
# from cheshire_cat_api.api.large_language_model_api import LargeLanguageModelApi
# from cheshire_cat_api.api.memory_api import MemoryApi
# from cheshire_cat_api.api.plugins_api import PluginsApi
# from cheshire_cat_api.api.rabbit_hole_api import RabbitHoleApi
# from cheshire_cat_api.api.settings_api import SettingsApi
# from cheshire_cat_api.api.status_api import StatusApi
#
# # import ApiClient
# from cheshire_cat_api.api_response import ApiResponse
# from cheshire_cat_api.api_client import ApiClient
# from cheshire_cat_api.configuration import Configuration
# from cheshire_cat_api.exceptions import OpenApiException
# from cheshire_cat_api.exceptions import ApiTypeError
# from cheshire_cat_api.exceptions import ApiValueError
# from cheshire_cat_api.exceptions import ApiKeyError
# from cheshire_cat_api.exceptions import ApiAttributeError
# from cheshire_cat_api.exceptions import ApiException
#
# # import models into sdk package
# from cheshire_cat_api.models.body_upload_url import BodyUploadUrl
# from cheshire_cat_api.models.http_validation_error import HTTPValidationError
# from cheshire_cat_api.models.location_inner import LocationInner
# from cheshire_cat_api.models.setting_body import SettingBody
# from cheshire_cat_api.models.validation_error import ValidationError
# from cheshire_cat_api.models.value import Value
